// Define the dimensions and margins for the scatter plot
const margin = { top: 50, right: 50, bottom: 50, left: 50 };
const width = 800 - margin.left - margin.right;
const height = 500 - margin.top - margin.bottom;

// Append SVG element to the body
const svg = d3
  .select('#scatter-plot')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',' + margin.top + ')',
  );

// Load the data
d3.csv(
  'https://gist.githubusercontent.com/SirishaManthena/143d8a4e801946f7437aec508d8f5254/raw/c138d08f102c2b8c7d61957ef9dba2d25e37cf42/nutritionalinfo.csv',
).then(function (data) {
  // Convert strings to numbers
  data.forEach(function (d) {
    d.Calories = +d.Calories;
    d['Total Fat'] = +d['Total Fat'];
  });

  // Define scales for x and y axes
  const xScale = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d['Total Fat'])])
    .range([0, width]);

  const yScale = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d.Calories)])
    .range([height, 0]);

  // Add x-axis
  svg
    .append('g')
    .attr('transform', 'translate(0,' + height + ')')
    .call(d3.axisBottom(xScale))
    .selectAll('text')
    .style('font-size', '12px')
    .style('fill', '#555');

  // Add y-axis
  svg
    .append('g')
    .call(d3.axisLeft(yScale))
    .selectAll('text')
    .style('font-size', '12px')
    .style('fill', '#555');

  // Add x-axis label
  svg
    .append('text')
    .attr('class', 'axis-label')
    .attr('x', width / 2)
    .attr('y', height + margin.bottom)
    .style('text-anchor', 'middle')
    .style('font-size', '14px')
    .text('Total Fat (g)');

  // Add y-axis label
  svg
    .append('text')
    .attr('class', 'axis-label')
    .attr('transform', 'rotate(-90)')
    .attr('x', 0 - height / 2)
    .attr('y', 0 - margin.left)
    .attr('dy', '1em')
    .style('text-anchor', 'middle')
    .style('font-size', '14px')
    .text('Calories');

  // Add scatter plot dots
  svg
    .selectAll('.dot')
    .data(data)
    .enter()
    .append('circle')
    .attr('class', 'dot')
    .attr('cx', (d) => xScale(d['Total Fat']))
    .attr('cy', (d) => yScale(d.Calories))
    .attr('r', 4) // Reduce the radius of the dots
    .attr('fill', '#4682B4') // Change the fill color of the dots
    .style('opacity', 0.8) // Set the opacity of the dots
    .style('transition', 'all 0.3s ease') // Add transition for smooth animation
    .on('mouseover', function (event, d) {
      // Add mouseover effect
      d3.select(this)
        .attr('r', 6) // Increase the radius on mouseover
        .style('opacity', 1); // Increase opacity on mouseover
    })
    .on('mouseout', function (event, d) {
      // Add mouseout effect
      d3.select(this)
        .attr('r', 4) // Restore original radius on mouseout
        .style('opacity', 0.8); // Restore original opacity on mouseout
    });

  // Add title
  svg
    .append('text')
    .attr('x', width / 2)
    .attr('y', 0 - margin.top / 2)
    .attr('text-anchor', 'middle')
    .style('font-size', '18px')
    .style('text-decoration', 'underline')
    .text('Calories vs. Total Fat');

  // Add gridlines
  svg
    .append('g')
    .attr('class', 'grid')
    .attr('transform', 'translate(0,' + height + ')')
    .call(
      d3
        .axisBottom(xScale)
        .tickSize(-height)
        .tickFormat('')
        .ticks(5),
    )
    .selectAll('.tick')
    .style('opacity', 0.1);

  svg
    .append('g')
    .attr('class', 'grid')
    .call(
      d3
        .axisLeft(yScale)
        .tickSize(-width)
        .tickFormat('')
        .ticks(5),
    )
    .selectAll('.tick')
    .style('opacity', 0.1);
});
